@@ -3,7 +3,7 @@ package Acme::PERLANCAR::Dummy::POD::LinkToSection;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-26'; # DATE
 our $DIST = 'Acme-PERLANCAR-Dummy'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 1;
 # ABSTRACT: Testing POD section links
@@ -20,7 +20,7 @@ Acme::PERLANCAR::Dummy::POD::LinkToSection - Testing POD section links
 
 =head1 VERSION
 
-This document describes version 0.010 of Acme::PERLANCAR::Dummy::POD::LinkToSection (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-07-26.
+This document describes version 0.011 of Acme::PERLANCAR::Dummy::POD::LinkToSection (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-07-26.
 
 =head1 LINK TARGETS
 
@@ -263,10 +263,12 @@ Link to section Subheading 2 (a =head2): L</Subheading 2>.
 Link to section Foo::Bar (a =head2 but text is inside a module link: =head2 LE<lt>Foo::BarE<gt>):
 L</Foo::Bar>. On MetaCPAN, it works.
 
-Link to section Baz (an =item): L</Baz>. On MetaCPAN, it works.
+Link to section Baz (an =item): L</Baz>. On MetaCPAN, it sometimes works but
+sometimes does not.
 
 Link to section Baz (an =item but text is inside a link: =item *
-LE<lt>Quux::CorgeE<gt>): L</Quux::Corge>.
+LE<lt>Quux::CorgeE<gt>): L</Quux::Corge>. On MetaCPAN, it sometimes works but
+sometimes does not.
 
 =head1 TODO
 
